@@ -88,7 +88,7 @@ PoCompendium::PoCompendium(TQObject *parent, const char *name)
 
 
     loadTimer = new TQTimer(this);
-    connect(loadTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(slotLoadCompendium()));
+    connect(loadTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(slotLoadCompendium()));
 }
 
 PoCompendium::~PoCompendium()
@@ -164,9 +164,9 @@ PrefWidget *PoCompendium::preferencesWidget(TQWidget *parent)
 {
     prefWidget = new CompendiumPreferencesWidget(parent,"pocompendium_prefwidget");
     kdDebug(KBABEL_SEARCH) << "PreferencesWidget is " << prefWidget << endl;
-    connect(prefWidget, TQT_SIGNAL(applySettings()), this, TQT_SLOT(applySettings()));
-    connect(prefWidget, TQT_SIGNAL(restoreSettings())
-                    , this, TQT_SLOT(restoreSettings()));
+    connect(prefWidget, TQ_SIGNAL(applySettings()), this, TQ_SLOT(applySettings()));
+    connect(prefWidget, TQ_SIGNAL(restoreSettings())
+                    , this, TQ_SLOT(restoreSettings()));
 
     restoreSettings();
     
@@ -828,7 +828,7 @@ void PoCompendium::slotLoadCompendium()
         }
         else
         {
-            connect(data, TQT_SIGNAL(progressEnds()), this, TQT_SLOT(recheckData()));
+            connect(data, TQ_SIGNAL(progressEnds()), this, TQ_SLOT(recheckData()));
         }
     }
     else
@@ -847,7 +847,7 @@ void PoCompendium::recheckData()
 {
     if(data)
     {
-        disconnect(data, TQT_SIGNAL(progressEnds()), this, TQT_SLOT(recheckData()));
+        disconnect(data, TQ_SIGNAL(progressEnds()), this, TQ_SLOT(recheckData()));
 
         error = data->hasErrors();
         errorMsg = data->errorMsg();
@@ -1153,14 +1153,14 @@ void PoCompendium::unregisterData()
 {
     if(data)
     { 
-        disconnect(data, TQT_SIGNAL(progressStarts(const TQString&)), this
-            , TQT_SIGNAL(progressStarts(const TQString&)));
-        disconnect(data, TQT_SIGNAL(progressEnds()), this , TQT_SIGNAL(progressEnds()));
-        disconnect(data, TQT_SIGNAL(progress(int)), this , TQT_SIGNAL(progress(int)));
+        disconnect(data, TQ_SIGNAL(progressStarts(const TQString&)), this
+            , TQ_SIGNAL(progressStarts(const TQString&)));
+        disconnect(data, TQ_SIGNAL(progressEnds()), this , TQ_SIGNAL(progressEnds()));
+        disconnect(data, TQ_SIGNAL(progress(int)), this , TQ_SIGNAL(progress(int)));
 
         if(data->active())
         {
-            disconnect(data,TQT_SIGNAL(progressEnds()),this,TQT_SLOT(recheckData()));
+            disconnect(data,TQ_SIGNAL(progressEnds()),this,TQ_SLOT(recheckData()));
         }
 
         if(data->unregisterObject(this))
@@ -1171,7 +1171,7 @@ void PoCompendium::unregisterData()
             }
             else
             {
-                connect(data,TQT_SIGNAL(progressEnds()),this,TQT_SLOT(removeData()));
+                connect(data,TQ_SIGNAL(progressEnds()),this,TQ_SLOT(removeData()));
             }
         }
 
@@ -1195,16 +1195,16 @@ void PoCompendium::registerData()
         emit progressStarts(i18n("Loading PO compendium"));
     }
     
-    connect(data, TQT_SIGNAL(
+    connect(data, TQ_SIGNAL(
     progressStarts(const TQString&)), this
-            , TQT_SIGNAL(progressStarts(const TQString&)));
-    connect(data, TQT_SIGNAL(progressEnds()), this , TQT_SIGNAL(progressEnds()));
-    connect(data, TQT_SIGNAL(progress(int)), this , TQT_SIGNAL(progress(int)));
+            , TQ_SIGNAL(progressStarts(const TQString&)));
+    connect(data, TQ_SIGNAL(progressEnds()), this , TQ_SIGNAL(progressEnds()));
+    connect(data, TQ_SIGNAL(progress(int)), this , TQ_SIGNAL(progress(int)));
 }
 
 void PoCompendium::removeData()
 {
-    const TQObject *s=TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s=sender();
     if(s && s->inherits("CompendiumData"))
     {
         const CompendiumData *d=static_cast<const CompendiumData*>(s);
