@@ -1,5 +1,8 @@
 #include <tqintdict.h>
 #include <stdio.h>
+#ifdef Q_OS_SOLARIS
+#include <strings.h> /* index(), rindex() */
+#endif
 #include <tqstringlist.h>
 #include <tqstrlist.h>
 #include <tqtextstream.h>
