@@ -36,7 +36,7 @@ using namespace Diff2;
 
 KompareSplitter::KompareSplitter( ViewSettings *settings, TQWidget * parent,
                                   const char *name) :
-	TQSplitter(Qt::Horizontal, parent, name ),
+	TQSplitter(TQt::Horizontal, parent, name ),
 	m_settings( settings )
 {
 	TQFrame *scrollFrame = new TQFrame( parent, "scrollFrame" );
@@ -46,9 +46,9 @@ KompareSplitter::KompareSplitter( ViewSettings *settings, TQWidget * parent,
 	scrollFrame->setFrameStyle( TQFrame::NoFrame | TQFrame::Plain );
 	scrollFrame->setLineWidth(scrollFrame->style().pixelMetric(TQStyle::PM_DefaultFrameWidth));
 	TQGridLayout *pairlayout = new TQGridLayout(scrollFrame, 2, 2, 0);
-	m_vScroll = new TQScrollBar( Qt::Vertical, scrollFrame );
+	m_vScroll = new TQScrollBar( TQt::Vertical, scrollFrame );
 	pairlayout->addWidget( m_vScroll, 0, 1 );
-	m_hScroll = new TQScrollBar( Qt::Horizontal, scrollFrame );
+	m_hScroll = new TQScrollBar( TQt::Horizontal, scrollFrame );
 	pairlayout->addWidget( m_hScroll, 1, 0 );
 
 	new KompareListViewFrame(true, m_settings, this, "source");
@@ -66,19 +66,19 @@ KompareSplitter::KompareSplitter( ViewSettings *settings, TQWidget * parent,
 	setOpaqueResize( true );
 	setFocusPolicy( TQWidget::WheelFocus );
 
-	connect( this, TQT_SIGNAL(configChanged()), TQT_SLOT(slotConfigChanged()) );
-	connect( this, TQT_SIGNAL(configChanged()), TQT_SLOT(slotDelayedRepaintHandles()) );
-	connect( this, TQT_SIGNAL(configChanged()), TQT_SLOT(slotDelayedUpdateScrollBars()) );
+	connect( this, TQ_SIGNAL(configChanged()), TQ_SLOT(slotConfigChanged()) );
+	connect( this, TQ_SIGNAL(configChanged()), TQ_SLOT(slotDelayedRepaintHandles()) );
+	connect( this, TQ_SIGNAL(configChanged()), TQ_SLOT(slotDelayedUpdateScrollBars()) );
 	
 	// scrolling
-	connect( m_vScroll, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(scrollToId(int)) );
-	connect( m_vScroll, TQT_SIGNAL(sliderMoved(int)),  TQT_SLOT(scrollToId(int)) );
-	connect( m_hScroll, TQT_SIGNAL(valueChanged(int)), TQT_SIGNAL(setXOffset(int)) );
-	connect( m_hScroll, TQT_SIGNAL(sliderMoved(int)),  TQT_SIGNAL(setXOffset(int)) );
+	connect( m_vScroll, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(scrollToId(int)) );
+	connect( m_vScroll, TQ_SIGNAL(sliderMoved(int)),  TQ_SLOT(scrollToId(int)) );
+	connect( m_hScroll, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(setXOffset(int)) );
+	connect( m_hScroll, TQ_SIGNAL(sliderMoved(int)),  TQ_SIGNAL(setXOffset(int)) );
 
 	m_scrollTimer=new TQTimer();
 	restartTimer = false;
-	connect (m_scrollTimer, TQT_SIGNAL(timeout()), TQT_SLOT(timerTimeout()) );
+	connect (m_scrollTimer, TQ_SIGNAL(timeout()), TQ_SLOT(timerTimeout()) );
 
 	// we need to receive childEvents now so that d->list is ready for when
 	// slotSetSelection(...) arrives
@@ -229,7 +229,7 @@ void KompareSplitter::moveSplitter( TQCOORD p, int id )
 	int* ws = new int[d->list.count()];
 	TQWidget *w = 0;
 	bool upLeft;
-	if ( TQApplication::reverseLayout() && orient ==Qt::Horizontal ) {
+	if ( TQApplication::reverseLayout() && orient ==TQt::Horizontal ) {
 		int q = p + s->wid->width();
 		doMove( FALSE, q, id - 1, -1, (p > max), poss, ws );
 		doMove( TRUE, q, id, -1, (p < min), poss, ws );
@@ -408,7 +408,7 @@ void KompareSplitter::repaintHandles()
 void KompareSplitter::wheelEvent( TQWheelEvent* e )
 {
 	// scroll lines...
-	if ( e->orientation() == Qt::Vertical )
+	if ( e->orientation() == TQt::Vertical )
 	{
 		if ( e->state() & TQt::ControlButton )
 			if ( e->delta() < 0 ) // scroll down one page
@@ -502,7 +502,7 @@ void KompareSplitter::scrollToId( int id )
 
 void KompareSplitter::slotDelayedUpdateScrollBars()
 {
-	TQTimer::singleShot( 0, this, TQT_SLOT( slotUpdateScrollBars() ) );
+	TQTimer::singleShot( 0, this, TQ_SLOT( slotUpdateScrollBars() ) );
 }
 
 void KompareSplitter::slotUpdateScrollBars()
@@ -543,7 +543,7 @@ void KompareSplitter::slotUpdateScrollBars()
 
 void KompareSplitter::slotDelayedUpdateVScrollValue()
 {
-	TQTimer::singleShot( 0, this, TQT_SLOT( slotUpdateVScrollValue() ) );
+	TQTimer::singleShot( 0, this, TQ_SLOT( slotUpdateVScrollValue() ) );
 }
 
 void KompareSplitter::slotUpdateVScrollValue()
