@@ -1624,7 +1624,7 @@ void tdeio_svnProtocol::wc_resolve( const KURL& wc, bool recurse ) {
 
 extern "C"
 {
-	KDE_EXPORT int kdemain(int argc, char **argv)    {
+	TDE_EXPORT int kdemain(int argc, char **argv)    {
 		TDEInstance instance( "tdeio_svn" );
 
 		kdDebug(7128) << "*** Starting tdeio_svn " << endl;
